@@ -246,13 +246,17 @@ public abstract class AccessControllerBean implements javax.ejb.SessionBean {
 	 * @see com.clustercontrol.accesscontrol.factory.LoginUserModifier#addUser(Property, String, String)
 	 */
 	public void addUser(Property property) throws NamingException, CreateException, FinderException, ParseException {
-		/** メイン処理 */
 		try {
+			/** メイン処理 */
 			LoginUserModifier.addUser(property, m_context.getCallerPrincipal().getName());
 		} catch (CreateException e) {
+			m_log.warn("addUser() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
 			m_context.setRollbackOnly();
 			throw e;
 		} catch (ParseException e) {
+			m_log.warn("addUser() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
 			m_context.setRollbackOnly();
 			throw e;
 		}
