@@ -698,10 +698,13 @@ public class JobStartInfoDAOImpl implements JobStartInfoDAO {
 			sqlMaster.append("FROM cc_job_mst, cc_job_start_mst ");
 			sqlMaster.append("WHERE ");
 			sqlMaster.append("(cc_job_mst.job_id=cc_job_start_mst.job_id ");
+			sqlMaster.append("AND cc_job_mst.jobunit_id=cc_job_start_mst.jobunit_id ");
 			sqlMaster.append("AND cc_job_mst.job_id= ? ");
 			sqlMaster.append("AND cc_job_mst.jobunit_id= ? ");
 			sqlMaster.append(")");
 			
+			m_log.debug("makeSession() sqlMaster : sql=" + sqlMaster.toString());
+			
 			//SQL文のセット(マスタ検索)
 			stmtMaster = connMaster.prepareStatement(sqlMaster.toString());
 			
