@@ -280,11 +280,32 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 		// Check
 		////////////////
 		// ジョブユニットID重複チェック
-		JobUtil.findDuplicateJobunitId(item);
+		try {
+			JobUtil.findDuplicateJobunitId(item);
+		} catch (JobInvalidException e) {
+			m_log.warn("registerJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
 		// ジョブユニット内ジョブID重複チェック
-		JobUtil.findDuplicateJobId(item, true);
+		try {
+			JobUtil.findDuplicateJobId(item, true);
+		} catch (JobInvalidException e) {
+			m_log.warn("registerJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
 		// 待ち条件チェック
-		JobUtil.checkWaitRule(item);
+		try {
+			JobUtil.checkWaitRule(item);
+		} catch (JobInvalidException e) {
+			m_log.warn("registerJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
 
 		////////////////
 		// Main
@@ -311,14 +332,18 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 		Collection<JobMasterLocal> registeredJobunits;
 		try {
 			registeredJobunits = JobMasterUtil.getLocalHome().findByJobType(JobConstant.TYPE_JOBUNIT);
-		} catch (FinderException e1) {
-			m_log.warn("JobMasterUtil.getLocalHome().findByJobType() : " + e1.getMessage());
-			JobMasterNotFoundException je = new JobMasterNotFoundException(e1.getMessage(), e1);
+		} catch (FinderException e) {
+			m_log.warn("registerJob() : findByJobType " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			JobMasterNotFoundException je = new JobMasterNotFoundException(e.getMessage(), e);
 			je.setJobType(JobConstant.TYPE_JOBUNIT);
+			m_context.setRollbackOnly();
 			throw je;
-		} catch (NamingException e1) {
-			m_log.error("registerJob() : " + e1.getMessage(), e1 ); 
-			throw new HinemosUnknownException(e1.getMessage(), e1);
+		} catch (NamingException e) {
+			m_log.error("registerJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		
 		////////////////
@@ -350,7 +375,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 				try {
 					JobControllerUtil.getLocalHome().create().deleteJobunit(mst.getJobunit_id());
 				} catch (Exception e) {
-					m_log.error("deleteJobunit : " + mst.getJobunit_id() + " : " + e.getMessage(), e);
+					m_log.error("registerJob() : deleteJobunit=" + mst.getJobunit_id() + ", " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
 					error = true;
 					errorJobunitIdList.add(mst.getJobunit_id());
 				}
@@ -370,15 +396,16 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			try {
 				// 登録処理に失敗した場合、ジョブユニットIDを記録する
 				if(JobUtil.isReferableJobunit(jobunit, loginUser)){
-					m_log.debug("registerJobunit : replace jobunit " + jobunit.getData().getJobunitId());
+					m_log.debug("registerJob() : registerJobunit : replace jobunit " + jobunit.getData().getJobunitId());
 					JobControllerUtil.getLocalHome().create().registerJobunit(jobunit);
 				}
 				else {
-					m_log.debug("registerJobunit : not replace jobunit " + jobunit.getData().getJobunitId() 
+					m_log.debug("registerJob() : registerJobunit : not replace jobunit " + jobunit.getData().getJobunitId() 
 							+ ", because this jobunit is not referable by " + loginUser);
 				}
 			} catch (Exception e) {
-				m_log.error("registerJobunit : " + jobunit.getData().getJobunitId() + " : " + e.getMessage(), e);
+				m_log.error("registerJob() : registerJobunit=" + jobunit.getData().getJobunitId() + ", " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
 				error = true;
 				errorJobunitIdList.add(jobunit.getData().getJobunitId());
 			}
@@ -387,6 +414,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 		// 登録処理に失敗していたらExceptionをスローする
 		if (error) {
 			String[] args = {errorJobunitIdList.toString()};
+			m_context.setRollbackOnly();
 			throw new JobInvalidException(Messages.getString("message.job.67", args));
 		}
 	}
@@ -423,20 +451,45 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			modify.deleteJobunit(jobunit.getData().getJobunitId(), loginUser);
 			modify.registerJobunit(jobunit, loginUser);
 		} catch (EJBException e) {
-			m_log.error("registerJobunit() : " + e.getMessage(), e ); 
+			m_log.error("registerJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (NamingException e) {
-			m_log.error("registerJobunit() : " + e.getMessage(), e ); 
+			m_log.error("registerJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (RemoveException e) {
-			m_log.error("registerJobunit() : " + e.getMessage(), e ); 
+			m_log.error("registerJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (CreateException e) {
-			m_log.error("registerJobunit() : " + e.getMessage(), e ); 
+			m_log.error("registerJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (JobInvalidException e) {
-			m_log.warn("registerJobunit() : " + e.getMessage()); 
+			m_log.error("registerJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
+		} catch (NotifyNotFoundException e) {
+			m_log.error("registerJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (HinemosUnknownException e) {
+			m_log.error("registerJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (JobMasterNotFoundException e) {
+			m_log.error("registerJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
 		}
 		
 	}
@@ -468,20 +521,45 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			ModifyJob modify = new ModifyJob();
 			modify.deleteJobunit(jobunitId, loginUser);
 		} catch (EJBException e) {
-			m_log.error("deleteJobunit() : " + e.getMessage(), e ); 
+			m_log.error("deleteJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (NamingException e) {
-			m_log.error("deleteJobunit() : " + e.getMessage(), e ); 
+			m_log.error("deleteJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (RemoveException e) {
-			m_log.error("deleteJobunit() : " + e.getMessage(), e ); 
+			m_log.error("deleteJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (CreateException e) {
-			m_log.error("deleteJobunit() : " + e.getMessage(), e ); 
+			m_log.error("deleteJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (JobInvalidException e) {
-			m_log.warn("registerJobunit() : " + e.getMessage()); 
+			m_log.warn("deleteJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
+		} catch (NotifyNotFoundException e) {
+			m_log.warn("deleteJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (HinemosUnknownException e) {
+			m_log.warn("deleteJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (JobMasterNotFoundException e) {
+			m_log.warn("deleteJobunit() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
 		}
 		
 	}
@@ -576,21 +654,49 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {jobId};
             apllog.put("SYS", "003", args);
-            m_log.debug("runJob() : " + e.getMessage());
-            m_log.error("runJob() : " + e.getMessage(), e);
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         } catch (NamingException e) {
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {jobId};
             apllog.put("SYS", "003", args);
-            m_log.debug("runJob() : " + e.getMessage());
-            m_log.error("runJob() : " + e.getMessage(), e);
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         } catch (FacilityNotFoundException e) {
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {jobId};
             apllog.put("SYS", "003", args);
-            m_log.debug("runJob() : " + e.getMessage());
+			m_log.warn("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+            throw e;
+		} catch (HinemosUnknownException e) {
+            AplLogger apllog = new AplLogger("JOB", "job");
+            String[] args = {jobId};
+            apllog.put("SYS", "003", args);
+			m_log.warn("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+            throw e;
+		} catch (JobMasterNotFoundException e) {
+            AplLogger apllog = new AplLogger("JOB", "job");
+            String[] args = {jobId};
+            apllog.put("SYS", "003", args);
+			m_log.warn("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+            throw e;
+		} catch (JobInfoNotFoundException e) {
+            AplLogger apllog = new AplLogger("JOB", "job");
+            String[] args = {jobId};
+            apllog.put("SYS", "003", args);
+			m_log.warn("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw e;
 		}
         
@@ -602,12 +708,25 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {sessionId, jobId};
             apllog.put("SYS", "002", args);
-            m_log.debug("runJob() : " + e.getMessage());
-            m_log.error("runJob() : " + e.getMessage(), e);
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         } catch (CreateException e) {
-        	m_log.error("runJob() : " + e.getMessage(), e);
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
+		} catch (HinemosUnknownException e) {
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+            throw e;
+		} catch (JobInfoNotFoundException e) {
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+            throw e;
 		}
 	}
 	
@@ -631,7 +750,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	 * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#runJob(String, String)
 	 */
 	public void runJob(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo) 
-			throws FacilityNotFoundException, HinemosUnknownException, JobInfoNotFoundException, JobMasterNotFoundException {
+	throws FacilityNotFoundException, HinemosUnknownException, JobInfoNotFoundException, JobMasterNotFoundException {
 	    m_log.debug("runJob() : jobId=" + jobId);
 	    
 	    String sessionId = null;
@@ -643,21 +762,49 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	    	AplLogger apllog = new AplLogger("JOB", "job");
 	    	String[] args = {jobId};
 	    	apllog.put("SYS", "003", args);
-	    	m_log.debug("runJob() : " + e.getMessage());
-	    	m_log.error("runJob() : " + e.getMessage(), e ); 
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 	    	throw new HinemosUnknownException(e.getMessage(), e);
 	    } catch (NamingException e) {
 	    	AplLogger apllog = new AplLogger("JOB", "job");
 	    	String[] args = {jobId};
 	    	apllog.put("SYS", "003", args);
-	    	m_log.debug("runJob() : " + e.getMessage());
-	    	m_log.error("runJob() : " + e.getMessage(), e ); 
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 	    	throw new HinemosUnknownException(e.getMessage(), e);
 	    } catch (FacilityNotFoundException e) {
 	    	AplLogger apllog = new AplLogger("JOB", "job");
 	    	String[] args = {jobId};
 	    	apllog.put("SYS", "003", args);
-	    	m_log.debug("runJob() : " + e.getMessage());
+			m_log.warn("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+	    	throw e;
+		} catch (HinemosUnknownException e) {
+	    	AplLogger apllog = new AplLogger("JOB", "job");
+	    	String[] args = {jobId};
+	    	apllog.put("SYS", "003", args);
+			m_log.warn("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+	    	throw e;
+		} catch (JobMasterNotFoundException e) {
+	    	AplLogger apllog = new AplLogger("JOB", "job");
+	    	String[] args = {jobId};
+	    	apllog.put("SYS", "003", args);
+			m_log.warn("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+	    	throw e;
+		} catch (JobInfoNotFoundException e) {
+	    	AplLogger apllog = new AplLogger("JOB", "job");
+	    	String[] args = {jobId};
+	    	apllog.put("SYS", "003", args);
+			m_log.warn("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 	    	throw e;
 		}
 	    
@@ -669,12 +816,25 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {sessionId, jobId};
             apllog.put("SYS", "002", args);
-            m_log.debug("runJob() : " + e.getMessage());
-            m_log.error("runJob() : " + e.getMessage(), e ); 
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 	    	throw new HinemosUnknownException(e.getMessage(), e);
         } catch (CreateException e) {
-        	m_log.error("runJob() : " + e.getMessage(), e ); 
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 	    	throw new HinemosUnknownException(e.getMessage(), e);
+		} catch (HinemosUnknownException e) {
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+	    	throw e;
+		} catch (JobInfoNotFoundException e) {
+			m_log.error("runJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+	    	throw e;
 		}
 	}
 	
@@ -702,7 +862,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#runJob(String, String, JobTriggerInfo)
 	 */
 	public void scheduleRunJob(String jobunitId, String jobId, String calendarId, JobTriggerInfo triggerInfo)
-			throws FacilityNotFoundException, HinemosUnknownException, JobInfoNotFoundException, CalendarNotFountException, JobMasterNotFoundException {
+	throws FacilityNotFoundException, HinemosUnknownException, JobInfoNotFoundException, CalendarNotFountException, JobMasterNotFoundException {
 	    m_log.debug("runJob() : jobId=" + jobId + ", calendarId=" + calendarId);
 	    
     	//カレンダをチェック
@@ -727,21 +887,42 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			//ジョブ実行
 			runJob(jobunitId, jobId, triggerInfo);
 		} catch (CreateException e) {
-			m_log.error("scheduleRunJob() : " + e.getMessage(), e ); 
+			m_log.error("scheduleRunJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 	    	throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (NamingException e) {
-			m_log.error("scheduleRunJob() : " + e.getMessage(), e ); 
+			m_log.error("scheduleRunJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 	    	throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (FacilityNotFoundException e) {
-			m_log.debug("scheduleRunJob() -> " + e.getMessage());
+			m_log.warn("scheduleRunJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (CalendarNotFountException e) {
-			m_log.debug("scheduleRunJob() -> " + e.getMessage());
+			m_log.warn("scheduleRunJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (JobMasterNotFoundException e) {
 			AplLogger apllog = new AplLogger(HinemosModuleConstant.JOB, "job");
 			String[] args = { jobId, triggerInfo.getTrigger_info() };
 			apllog.put("SYS", "016", args);
+			m_log.warn("scheduleRunJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (HinemosUnknownException e) {
+			m_log.warn("scheduleRunJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (JobInfoNotFoundException e) {
+			m_log.warn("scheduleRunJob() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		}
 	}
@@ -772,20 +953,36 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean#ejbHomeMakeSession(String, NotifyRequestMessage)
 	 */
 	public String createJobInfo(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo)
-			throws FacilityNotFoundException, HinemosUnknownException, JobMasterNotFoundException, JobInfoNotFoundException {
-	    m_log.debug("createJobInfo() : jobId=" + jobId);
+	throws FacilityNotFoundException, HinemosUnknownException, JobMasterNotFoundException, JobInfoNotFoundException {
+		m_log.debug("createJobInfo() : jobId=" + jobId);
 
-	    try {
+		try {
 			return JobSessionUtil.getLocalHome().makeSession(jobunitId, jobId, info, triggerInfo);
 		} catch (FacilityNotFoundException e) {
-			m_log.debug("createJobInfo() -> " + e.getMessage());
+			m_log.warn("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (CreateException e) {
-			m_log.error("createJobInfo() : " + e.getMessage(), e ); 
+			m_log.error("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (NamingException e) {
-			m_log.error("createJobInfo() : " + e.getMessage(), e ); 
+			m_log.error("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
+		} catch (JobMasterNotFoundException e) {
+			m_log.error("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (JobInfoNotFoundException e) {
+			m_log.error("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
 		}
 	}
 
@@ -810,11 +1007,25 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			JobRunManagementLocal JobRunManagement = JobRunManagementUtil.getLocalHome().create();
 			JobRunManagement.operationJob(property);
 		} catch (CreateException e) {
-			m_log.error("createJobInfo() : " + e.getMessage(), e ); 
+			m_log.error("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (NamingException e) {
-			m_log.error("createJobInfo() : " + e.getMessage(), e ); 
+			m_log.error("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
+		} catch (HinemosUnknownException e) {
+			m_log.error("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (JobInfoNotFoundException e) {
+			m_log.error("createJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
 		}
 	}
 	
@@ -849,10 +1060,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectJob select = new SelectJob();
 			list = select.getHistoryList(userId, null, histories);
 		} catch (NamingException e) {
-			m_log.error("getHistoryList() : " + e.getMessage(), e ); 
+			m_log.error("getHistoryList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (SQLException e) {
-			m_log.error("getHistoryList() : " + e.getMessage(), e ); 
+			m_log.error("getHistoryList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (JobInfoNotFoundException e) {
 			throw e;
@@ -893,10 +1106,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectJob select = new SelectJob();
 			list = select.getHistoryList(userId, property, histories);
 		} catch (NamingException e) {
-			m_log.error("getHistoryList() : " + e.getMessage(), e ); 
+			m_log.error("getHistoryList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (SQLException e) {
-			m_log.error("getHistoryList() : " + e.getMessage(), e ); 
+			m_log.error("getHistoryList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (JobInfoNotFoundException e) {
 			throw e;
@@ -936,7 +1151,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectJob select = new SelectJob();
 			item = select.getDetailList(sessionId);
 		} catch (NamingException e) {
-			m_log.error("getDetailList() : " + e.getMessage(), e ); 
+			m_log.error("getDetailList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 	    
@@ -978,7 +1194,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			m_log.error("getNodeDetailList() : " + e.getMessage(), e ); 
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (CreateException e) {
-			m_log.error("getNodeDetailList() : " + e.getMessage(), e ); 
+			m_log.error("getNodeDetailList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (JobInfoNotFoundException e) {
 			throw e;
@@ -1018,10 +1235,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectJob select = new SelectJob();
 			list = select.getForwardFileList(sessionId, jobunitId, jobId);
 		} catch (NamingException e) {
-			m_log.error("getForwardFileList() : " + e.getMessage(), e ); 
+			m_log.error("getForwardFileList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (CreateException e) {
-			m_log.error("getForwardFileList() : " + e.getMessage(), e ); 
+			m_log.error("getForwardFileList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (JobInfoNotFoundException e) {
 			throw e;
@@ -1056,19 +1275,25 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {info.getId(), info.getJobId()};
             apllog.put("SYS", "004", args);
-            m_log.debug("addSchedule() : " + e.getMessage());
+			m_log.error("addSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         } catch (NamingException e) {
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {info.getId(), info.getJobId()};
             apllog.put("SYS", "004", args);
-            m_log.error("addSchedule() : " + e.getMessage(), e ); 
+			m_log.error("addSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         } catch (SchedulerException e) {
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {info.getId(), info.getJobId()};
             apllog.put("SYS", "004", args);
-            m_log.debug("addSchedule() : " + e.getMessage());
+			m_log.warn("addSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         }
 	}
@@ -1099,19 +1324,25 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {info.getId()};
             apllog.put("SYS", "006", args);
-            m_log.error("modifySchedule() : " + e.getMessage(), e ); 
+			m_log.error("modifySchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         } catch (SchedulerException e) {
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {info.getId()};
             apllog.put("SYS", "006", args);
-            m_log.debug("modifySchedule() : " + e.getMessage());
+			m_log.warn("modifySchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         } catch (ParseException e) {
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {info.getId()};
             apllog.put("SYS", "006", args);
-            m_log.debug("modifySchedule() : " + e.getMessage());
+			m_log.warn("modifySchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         }
 	}
@@ -1140,13 +1371,17 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {scheduleId};
             apllog.put("SYS", "005", args);
-            m_log.error("deleteSchedule() : " + e.getMessage(), e ); 
+			m_log.error("deleteSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         } catch (SchedulerException e) {
             AplLogger apllog = new AplLogger("JOB", "job");
             String[] args = {scheduleId};
             apllog.put("SYS", "005", args);
-            m_log.debug("deleteSchedule() : " + e.getMessage());
+			m_log.warn("deleteSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw new HinemosUnknownException(e.getMessage(), e);
         }
 	}
@@ -1176,10 +1411,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectSchedule select = new SelectSchedule();
 			list = select.getScheduleList(m_context.getCallerPrincipal().getName());
 		} catch (NamingException e) {
-			m_log.error("getScheduleList() : " + e.getMessage(), e ); 
+			m_log.error("getScheduleList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (SchedulerException e) {
-			m_log.error("getScheduleList() : " + e.getMessage(), e ); 
+			m_log.error("getScheduleList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 
@@ -1211,14 +1448,16 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectRunSchedule select = new SelectRunSchedule();
 			list = select.getList(m_context.getCallerPrincipal().getName());
 		} catch (NamingException e) {
-			m_log.error("getRunScheduleList() : " + e.getMessage(), e ); 
+			m_log.error("getRunScheduleList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (SchedulerException e) {
-			m_log.error("getRunScheduleList() : " + e.getMessage(), e ); 
+			m_log.error("getRunScheduleList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 
-	    return list;
+		return list;
 	}
 	
 	/**
@@ -1248,10 +1487,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectRunSchedule select = new SelectRunSchedule();
 			list = select.getSchedule(base, m_context.getCallerPrincipal().getName());
 		} catch (NamingException e) {
-			m_log.error("getRunSchedule() : " + e.getMessage(), e ); 
+			m_log.error("getRunSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (SchedulerException e) {
-			m_log.error("getRunSchedule() : " + e.getMessage(), e ); 
+			m_log.error("getRunSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 
@@ -1285,7 +1526,8 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectRunSchedule select = new SelectRunSchedule();
 			item = select.getDetailList(scheduleId, jobunitId);
 		} catch (NamingException e) {
-			m_log.error("getRunScheduleDetailList() : " + e.getMessage(), e ); 
+			m_log.error("getRunScheduleDetailList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (SchedulerException e) {
 			throw new HinemosUnknownException(e.getMessage(), e);
@@ -1324,13 +1566,16 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectRunSchedule select = new SelectRunSchedule();
 			item = select.getDetailSchedule(scheduleId, jobunitId, base);
 		} catch (NamingException e) {
-			m_log.error("getRunScheduleDetail() : " + e.getMessage(), e ); 
+			m_log.error("getRunScheduleDetail() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (SchedulerException e) {
-			m_log.error("getRunScheduleDetail() : " + e.getMessage(), e ); 
+			m_log.error("getRunScheduleDetail() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (RemoteException e) {
-			m_log.error("getRunScheduleDetail() : " + e.getMessage(), e ); 
+			m_log.error("getRunScheduleDetail() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		return item;
@@ -1365,10 +1610,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			
 			list = calendar.getCalendarIdList();
 		} catch (CreateException e) {
-			m_log.error("getCalendarIdList() : " + e.getMessage(), e ); 
+			m_log.error("getCalendarIdList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (NamingException e) {
-			m_log.error("getCalendarIdList() : " + e.getMessage(), e ); 
+			m_log.error("getCalendarIdList() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		
@@ -1407,10 +1654,12 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			SelectJob select = new SelectJob();
 			item = select.getSessionJobInfo(sessionId, jobunitId, jobId);
 		} catch (NamingException e) {
-			m_log.error("getSessionJobInfo() : " + e.getMessage(), e ); 
+			m_log.error("getSessionJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		} catch (CreateException e) {
-			m_log.error("getSessionJobInfo() : " + e.getMessage(), e ); 
+			m_log.error("getSessionJobInfo() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		
@@ -1482,9 +1731,11 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 			}
 			
 		} catch (FinderException e) {
-			m_log.warn("isUseFacilityId() : " + e.getMessage());
+			m_log.warn("isUseFacilityId() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
 		} catch (NamingException e) {
-			m_log.warn("isUseFacilityId() : " + e.getMessage());
+			m_log.warn("isUseFacilityId() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
 		}
 	}
 }
