@@ -112,7 +112,7 @@ public class ModifyLogTransfer {
 				queue.put(info, DeliveryMode.PERSISTENT);
 				
 			} catch (Exception e) {
-				m_log.debug("modify() : 更新情報送信エラー : " + e.getMessage());
+				m_log.debug("modify() : Send Error : ", e);
 				
 			} finally {
 				if (queue != null) {
