@@ -34,6 +34,7 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.OutputBasicInfo;
+import com.clustercontrol.bean.OutputNotifyGroupInfo;
 import com.clustercontrol.commons.util.HinemosProperties;
 import com.clustercontrol.commons.util.JmsPersistenceConfig;
 import com.clustercontrol.commons.util.SendQueue;
@@ -150,11 +151,11 @@ public class SyslogDuplicationBean implements javax.ejb.MessageDrivenBean, javax
 			
 			try {
 				Object objMsg = msg.getObject();
-				if(objMsg instanceof NotifyRequestMessage) {
-					NotifyRequestMessage outputInfo = (NotifyRequestMessage)objMsg;
+				if(objMsg instanceof OutputNotifyGroupInfo) {
+					OutputNotifyGroupInfo outputInfo = (OutputNotifyGroupInfo)objMsg;
 					
 					// 重複確認の結果、重複していない場合は処理を行う
-					if(duplicationCheck(outputInfo.getOutputInfo())) {
+					if(duplicationCheck(outputInfo)) {
 						SendQueue queue = null;
 						try {
 							if (JmsPersistenceConfig.QUEUE_SYSLOG_MODE == DeliveryMode.NON_PERSISTENT) {
@@ -286,7 +287,7 @@ public class SyslogDuplicationBean implements javax.ejb.MessageDrivenBean, javax
 				
 				Collection<SyslogDuplicationInfoLocal> ct = SyslogDuplicationInfoUtil.getLocalHome().findOldRecode(new Timestamp(timeLeft));
 				
-				m_log.debug("removeOldRecode() : the number of records ： " + ct.size());
+				m_log.debug("removeOldRecode() : the number of records : " + ct.size());
 
 				Iterator<SyslogDuplicationInfoLocal> itr = ct.iterator();
 				while(itr.hasNext()){
