@@ -117,15 +117,21 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 	public boolean addNotify(NotifyInfo info) throws HinemosUnknownException, NotifyDuplicateException {
 		
 		Principal pri = m_context.getCallerPrincipal();
+		
 		// 通知情報を登録
 		AddNotify notify = new AddNotify();
 		boolean flag;
 		try {
 			flag = notify.add(info,pri.getName());
 		} catch (NotifyDuplicateException e) {
+			m_log.error("addNotify() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (Exception e){
-			m_log.error("addNotify(): " + e.getMessage(), e);
+			m_log.error("addNotify() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		
@@ -157,9 +163,14 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 		try {
 			flag = notify.modify(info,pri.getName());
 		} catch (NotifyDuplicateException e) {
+			m_log.error("modifyNotify() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (Exception e){
-			m_log.error("modifyNotify(): " + e.getMessage(), e);
+			m_log.error("modifyNotify() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		return flag;
@@ -189,9 +200,14 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 		try {
 			flag = notify.delete(notifyId);
 		} catch(NotifyNotFoundException e){
+			m_log.error("deleteNotify() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (Exception e){
-			m_log.error("deleteNotify(): " + e.getMessage(), e);
+			m_log.error("deleteNotify() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		return flag;
@@ -206,9 +222,6 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 	 *     role-name="NotifyRead"
 	 *     method-intf="Remote"
 	 * 
-	 * @jboss.method-attributes
-	 *     read-only="true"
-	 * 
 	 * @param notifyId 取得対象の通知ID
 	 * @return 通知情報
 	 * @throws NotifyNotFoundException
@@ -276,9 +289,6 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 	 *     role-name="NotifyRead"
 	 *     method-intf="Remote"
 	 * 
-	 * @jboss.method-attributes
-	 *     read-only="true"
-	 * 
 	 * @return 通知情報一覧（Objectの2次元配列）
 	 * @throws NotifyNotFoundException
 	 * @throws HinemosUnknownException
@@ -345,9 +355,6 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 	 *     role-name="NotifyRead"
 	 *     method-intf="Remote"
 	 * 
-	 * @jboss.method-attributes
-	 *     read-only="true"
-	 * 
 	 * @return 通知情報一覧（Objectの2次元配列）
 	 * @throws NotifyNotFoundException
 	 * @throws HinemosUnknownException
@@ -415,9 +422,6 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 	 *  unchecked="true"
 	 *     method-intf="both"
 	 * 
-	 * @jboss.method-attributes
-	 *     read-only="true"
-	 * 
 	 * @param notifyGroupId  通知グループID
 	 * @return 通知
 	 * @throws NotifyNotFoundException
@@ -465,9 +469,14 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 		try {
 			flag = notify.modify(info, notifyGroupId);
 		} catch (NotifyNotFoundException e){
+			m_log.error("modifyNotifyRelation() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (Exception e){
-			m_log.error("modifyNotifyRelation(Collection, String): " + e.getMessage(), e);
+			m_log.error("modifyNotifyRelation() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		return flag;
@@ -496,14 +505,48 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 		try {
 			flag = notify.delete(notifyGroupId);
 		} catch (NotifyNotFoundException e){
+			m_log.error("deleteNotifyRelation() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (Exception e){
-			m_log.error("deleteNotifyRelation(String): " + e.getMessage(), e);
+			m_log.error("deleteNotifyRelation() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		return flag;
 	}
 	
+	/**
+	 * syslog-ng監視の通知グループを削除します。
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+	 *  unchecked="true"
+	 *     method-intf="both"
+	 * 
+	 * @return 削除に成功した場合、<code> true </code>
+	 * @throws NotifyNotFoundException
+	 * @throws HinemosUnknownException
+	 * 
+	 */
+	public boolean deleteNotifyRelationSyslogNG() throws NotifyNotFoundException, HinemosUnknownException{
+		
+		// システム通知情報を削除
+		DeleteNotifyRelation notify = new DeleteNotifyRelation();
+		boolean flag;
+		try {
+			flag = notify.deleteSyslogNG();
+		} catch (NotifyNotFoundException e){
+			throw e;
+		} catch (Exception e){
+			m_log.error("deleteNotifyRelationSyslogNG(): " + e.getMessage(), e);
+			throw new HinemosUnknownException(e.getMessage(), e);
+		}
+		return flag;
+	}
 
 	/**
 	 * 通知グループを作成します。
@@ -529,7 +572,9 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 			try {
 				flag = notify.add(info);
 			} catch (Exception e){
-				m_log.error("addNotifyRelation(Collection): " + e.getMessage(), e);
+				m_log.error("addNotifyRelation() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
+				m_context.setRollbackOnly();
 				throw new HinemosUnknownException(e.getMessage(), e);
 			}
 			return flag;
@@ -559,9 +604,14 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 		try {
 		ret = notify.getNotifyGroupIdBaseOnNotifyId(notifyId);
 		} catch (NotifyNotFoundException e){
+			m_log.error("checkNotifyId() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (Exception e){
-			m_log.error("checkNotifyId(String): " + e.getMessage(), e);
+			m_log.error("checkNotifyId() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		return ret;
