@@ -54,7 +54,7 @@ public class CollectorDAOImpl implements CollectorDAO {
 	 * コンストラクター
 	 */
 	public CollectorDAOImpl() {
-		m_log.trace("コンストラクター in CollectorDAO");
+		m_log.trace("CollectorDAOImpl()");
 	}
 
 	/**
