@@ -270,7 +270,7 @@ public class TrapSnmpManager {
 			
 			// カレンダのチェック
 			String calendarId = info.getCalendarId();
-			m_log.debug("check calender.  MonitorID : " + info.getMonitorId() + ", CalendarID ： " + calendarId);
+			m_log.debug("check calender.  MonitorID : " + info.getMonitorId() + ", CalendarID : " + calendarId);
 			if(calendarId != null && !"".equals(calendarId)){
 				try {
 					// 稼働日か否かチェック
