@@ -28,14 +28,10 @@ import com.clustercontrol.JobInfoNotFoundException;
 import com.clustercontrol.JobInvalidException;
 import com.clustercontrol.JobMasterNotFoundException;
 import com.clustercontrol.NotifyNotFoundException;
-import com.clustercontrol.UsedFacilityException;
 import com.clustercontrol.UserNotFoundException;
-//import com.clustercontrol.bean.CommonTableTreeItem;
 import com.clustercontrol.bean.OutputBasicInfo;
-import com.clustercontrol.jobmanagement.bean.JobForwardFile;
 import com.clustercontrol.jobmanagement.bean.JobHistoryFilter;
 import com.clustercontrol.jobmanagement.bean.JobHistoryList;
-import com.clustercontrol.jobmanagement.bean.JobNodeDetail;
 import com.clustercontrol.jobmanagement.bean.JobSchedule;
 import com.clustercontrol.jobmanagement.bean.JobTreeItem;
 import com.clustercontrol.jobmanagement.bean.JobTriggerInfo;
@@ -44,6 +40,9 @@ import com.clustercontrol.jobmanagement.ejb.session.JobControllerLocal;
 import com.clustercontrol.jobmanagement.ejb.session.JobControllerUtil;
 import com.clustercontrol.notify.bean.NotifyRequestMessage;
 
+/**
+ * ジョブ操作用のWebAPIエンドポイント
+ */
 @javax.jws.WebService
 public class JobEndpoint {
 	protected static Log m_log = LogFactory.getLog( JobEndpoint.class );
@@ -77,6 +76,7 @@ public class JobEndpoint {
 	 * @throws NotifyNotFoundException 
 	 */
 	public JobTreeItem getJobTree(boolean treeOnly) throws HinemosUnknownException, NotifyNotFoundException, JobMasterNotFoundException, UserNotFoundException {
+		m_log.debug("getJobTree : treeOnly=" + treeOnly);
 		JobControllerLocal job = getJobControllerLocal();
 		return job.getJobTree(treeOnly, Locale.getDefault());
 	}
@@ -93,6 +93,8 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getJobTreeOneLevel(String, Locale)
 	 */
 	public JobTreeItem getJobTreeOneLevel(String parentJobunitId, String parentJobId) throws JobMasterNotFoundException, HinemosUnknownException {
+		m_log.debug("getJobTreeOneLevel : parentJobunitId=" + parentJobunitId +
+				", parentJobId=" + parentJobId);
 		JobControllerLocal job = getJobControllerLocal();
 		return job.getJobTreeOneLevel(parentJobunitId, parentJobId, Locale.getDefault());
 	}
@@ -107,6 +109,11 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.ModifyJob#registerJob(JobTreeItem, String)
 	 */
 	public void registerJob(JobTreeItem item) throws HinemosUnknownException, JobMasterNotFoundException, JobInvalidException {
+		String id = null;
+		if (item != null && item.getData() != null) {
+			id = item.getData().getId();
+		}
+		m_log.debug("registerJob : Id=" + id + ", item="+ item);
 		JobControllerLocal job = getJobControllerLocal();
 		job.registerJob(item);
 	}
@@ -122,6 +129,11 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.ModifyJob#registerJobunit(JobTreeItem, String)
 	 */
 	public void registerJobunit(JobTreeItem jobunit) throws NotifyNotFoundException, HinemosUnknownException, JobMasterNotFoundException {
+		String id = null;
+		if (jobunit!= null && jobunit.getData() != null) {
+			id = jobunit.getData().getId();
+		}
+		m_log.debug("registerJobunit : Id=" + id + ", jobunit="+ jobunit);
 		JobControllerLocal job = getJobControllerLocal();
 		job.registerJobunit(jobunit);
 	}
@@ -135,6 +147,7 @@ public class JobEndpoint {
 	 * @throws JobMasterNotFoundException 
 	 */
 	public void deleteJobunit(String jobunitId) throws NotifyNotFoundException, HinemosUnknownException, JobMasterNotFoundException {
+		m_log.debug("deleteJobunit : Id=" + jobunitId);
 		JobControllerLocal job = getJobControllerLocal();
 		job.deleteJobunit(jobunitId);
 	}
@@ -154,6 +167,8 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.JobOperationProperty#getStartProperty(String, String, String, String, Locale)
 	 */
 	public ArrayList<String> getAvailableStartOperation(String sessionId, String jobunitId, String jobId, String facilityId) throws HinemosUnknownException {
+		m_log.debug("getAvailableStartOperation : sessionId=" + sessionId +
+				", jobunitId=" + jobunitId + ", jobId=" + jobId + ", facilityId=" + facilityId);
 		JobControllerLocal job = getJobControllerLocal();
 		return job.getAvailableStartOperation(sessionId, jobunitId, jobId, facilityId, Locale.getDefault());
 	}
@@ -172,6 +187,8 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.JobOperationProperty#getStopProperty(String, String, String, String, Locale)
 	 */
 	public ArrayList<String> getAvailableStopOperation(String sessionId, String jobunitId,  String jobId, String facilityId) throws HinemosUnknownException {
+		m_log.debug("getAvailableStopOperation : sessionId=" + sessionId +
+				", jobunitId=" + jobunitId + ", jobId=" + jobId + ", facilityId=" + facilityId);
 		JobControllerLocal job = getJobControllerLocal();
 		return job.getAvailableStopOperation(sessionId, jobunitId, jobId, facilityId, Locale.getDefault());
 	}
@@ -191,6 +208,8 @@ public class JobEndpoint {
 	 */
 	public void runJob(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo) 
 			throws FacilityNotFoundException, HinemosUnknownException, JobInfoNotFoundException, JobMasterNotFoundException {
+		m_log.debug("runJob : jobunitId=" + jobunitId + ", jobId=" + jobId + ", info=" + info +
+				", triggerInfo=" + triggerInfo);
 		JobControllerLocal job = getJobControllerLocal();
 		job.runJob(jobunitId, jobId, info, triggerInfo);
 	}
@@ -213,6 +232,8 @@ public class JobEndpoint {
 	 */
 	public void scheduleRunJob(String jobunitId, String jobId, String calendarId, JobTriggerInfo triggerInfo)
 			throws FacilityNotFoundException, HinemosUnknownException, JobMasterNotFoundException, JobInfoNotFoundException, CalendarNotFountException {
+		m_log.debug("scheduleRunJob : jobunitId=" + jobunitId + ", jobId=" + jobId +
+				", calendarId=" + calendarId + ", triggerInfo=" + triggerInfo);
 		JobControllerLocal job = getJobControllerLocal();
 		job.scheduleRunJob(jobunitId, jobId, calendarId, triggerInfo);
 	}
@@ -234,6 +255,8 @@ public class JobEndpoint {
 	 */
 	public String createJobInfo(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo)
 			throws FacilityNotFoundException, HinemosUnknownException, JobMasterNotFoundException, JobInfoNotFoundException {
+		m_log.debug("createJobInfo : jobunitId=" + jobunitId + ", jobId=" + jobId +
+				", info=" + info + ", triggerInfo=" + triggerInfo);
 		JobControllerLocal job = getJobControllerLocal();
 		return job.createJobInfo(jobunitId, jobId, info, triggerInfo);
 	}
@@ -247,6 +270,7 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#operationJob(Property)
 	 */
 	public void operationJob(NodeOperationInfo property) throws HinemosUnknownException, JobInfoNotFoundException {
+		m_log.debug("operationJob : nodeOperationInfo=" + property);
 		JobControllerLocal job = getJobControllerLocal();
 		job.operationJob(property);
 	}
@@ -263,6 +287,7 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getHistoryList(Property, int)
 	 */
 	public JobHistoryList getHistoryList(JobHistoryFilter property, int histories) throws JobInfoNotFoundException, HinemosUnknownException {
+		m_log.debug("getHistoryList : jobHistoryFilter=" + property + ", histories=" + histories);
 		JobControllerLocal job = getJobControllerLocal();
 		return job.getHistoryList(property, histories);
 	}
@@ -333,6 +358,7 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.ModifySchedule#addSchedule(JobSchedule, String)
 	 */
 	public void addSchedule(JobSchedule info) throws HinemosUnknownException {
+		m_log.debug("addSchedule : jobSchedule=" + info);
 		JobControllerLocal job = getJobControllerLocal();
 		job.addSchedule(info);
 	}
@@ -346,6 +372,7 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.ModifySchedule#modifySchedule(JobSchedule, String)
 	 */
 	public void modifySchedule(JobSchedule info) throws HinemosUnknownException {
+		m_log.debug("modifySchedule : jobSchedule=" + info);
 		JobControllerLocal job = getJobControllerLocal();
 		job.modifySchedule(info);
 	}
@@ -359,6 +386,7 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.ModifySchedule#deleteSchedule(String)
 	 */
 	public void deleteSchedule(String scheduleId) throws HinemosUnknownException {
+		m_log.debug("deleteSchedule : scheduleId=" + scheduleId);
 		JobControllerLocal job = getJobControllerLocal();
 		job.deleteSchedule(scheduleId);
 	}
@@ -372,6 +400,7 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.SelectSchedule#getScheduleList()
 	 */
 	public ArrayList<JobSchedule> getScheduleList() throws JobMasterNotFoundException, HinemosUnknownException  {
+		m_log.debug("getScheduleList :");
 		JobControllerLocal job = getJobControllerLocal();
 		return job.getScheduleList();
 	}
@@ -388,6 +417,7 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.calendar.ejb.session.CalendarControllerBean#getCalendarIdList()
 	 */
 	public ArrayList<String> getCalendarIdList() throws HinemosUnknownException, CalendarNotFountException {
+		m_log.debug("getCalendarIdList :");
 		JobControllerLocal job = getJobControllerLocal();
 		return job.getCalendarIdList();
 	}
@@ -405,6 +435,8 @@ public class JobEndpoint {
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getSessionJobInfo(String, String, String)
 	 */
 	public JobTreeItem getSessionJobInfo(String sessionId, String jobunitId, String jobId) throws HinemosUnknownException, NotifyNotFoundException, JobInfoNotFoundException {
+		m_log.debug("getSessionJobInfo : sessionId=" + sessionId + ", jobunitId=" + jobunitId +
+				", jobId=" + jobId);
 		JobControllerLocal job = getJobControllerLocal();
 		return job.getSessionJobInfo(sessionId, jobunitId, jobId);
 	}
