@@ -32,6 +32,9 @@ import com.clustercontrol.repository.bean.ScopeInfo;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
 import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 
+/**
+ * リポジトリ操作用のWebAPIエンドポイント
+ */
 @javax.jws.WebService
 public class RepositoryEndpoint {
 	protected static Log m_log = LogFactory.getLog( RepositoryEndpoint.class );
@@ -72,6 +75,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<NodeInfo> getFilterNodeList(NodeInfo property) throws HinemosUnknownException {
+		m_log.debug("getFilterNodeList : nodeInfo=" + property);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getFilterNodeList(property);
 	}
@@ -94,6 +98,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<String> getExecTargetFacilityIdList(String facilityId) throws HinemosUnknownException {
+		m_log.debug("getExecTargetFacilityIdList : facilityId=" + facilityId);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getExecTargetFacilityIdList(facilityId);
 	}
@@ -111,6 +116,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public NodeInfo getNode(String facilityId) throws FacilityNotFoundException, HinemosUnknownException {
+		m_log.debug("getNode : facilityId=" + facilityId);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getNode(facilityId);
 	}
@@ -129,6 +135,8 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public String getFacilityPath(String facilityId, String parentFacilityId) throws HinemosUnknownException {
+		m_log.debug("getFacilityPath : facilityId=" + facilityId +
+				", parentFacilityId=" + parentFacilityId);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getFacilityPath(facilityId, parentFacilityId);
 	}
@@ -149,6 +157,8 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public NodeInfo getNodePropertyBySNMP(String ipAddress, int port, String community, String version) throws UnknownHostException, FacilityNotFoundException, HinemosUnknownException {
+		m_log.debug("getNodePropertyBySNMP : ipAddress=" + ipAddress + ", port=" + port + 
+				", community=" + community + ", version=" + version);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getNodePropertyBySNMP(ipAddress, port, community, version);
 	}
@@ -168,6 +178,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public void addNode(NodeInfo nodeInfo) throws FacilityDuplicateException, HinemosUnknownException {
+		m_log.debug("addNode : nodeInfo=" + nodeInfo);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		repository.addNode(nodeInfo);
 	}
@@ -184,6 +195,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public void modifyNode(NodeInfo property) throws HinemosUnknownException {
+		m_log.debug("modifyNode : nodeInfo=" + property);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		repository.modifyNode(property);
 	}
@@ -201,6 +213,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public void deleteNode(String facilityId) throws UsedFacilityException, HinemosUnknownException {
+		m_log.debug("deleteNode : facilityId=" + facilityId);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		repository.deleteNode(facilityId);
 	}
@@ -240,6 +253,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException
 	 */
 	public ScopeInfo getScopeProperty(String facilityId) throws FacilityNotFoundException, HinemosUnknownException {
+		m_log.debug("getScopeProperty : facilityId=" + facilityId);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getScopeProperty(facilityId);
 	}
@@ -257,6 +271,8 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public void addScope(String parentFacilityId, ScopeInfo property) throws FacilityDuplicateException, HinemosUnknownException {
+		m_log.debug("addScope : parentFacilityId=" + parentFacilityId +
+		", scopeInfo=" + property);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		repository.addScope(parentFacilityId, property);
 	}
@@ -273,6 +289,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public void modifyScope(ScopeInfo property) throws HinemosUnknownException {
+		m_log.debug("modifyScope : scopeInfo=" + property);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		repository.modifyScope(property);
 	}
@@ -287,6 +304,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public void deleteScope(String facilityId) throws UsedFacilityException, HinemosUnknownException {
+		m_log.debug("deleteScope : facilityId=" + facilityId);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		repository.deleteScope(facilityId);
 	}
@@ -310,6 +328,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<NodeInfo> getNodeList(String parentFacilityId, int level) throws HinemosUnknownException {
+		m_log.debug("getNodeList : parentFacilityId=" + parentFacilityId + ", level=" + level);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getNodeList(parentFacilityId, level);
 	}
@@ -332,6 +351,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<String> getNodeScopeList(String facilityId) throws HinemosUnknownException {
+		m_log.debug("getNodeScopeList : facilityId=" + facilityId);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getNodeScopeList(facilityId);
 	}
@@ -349,6 +369,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<String> getFacilityIdList(String parentFacilityId, int level) throws HinemosUnknownException {
+		m_log.debug("getFacilityIdList : parentFacilityId=" + parentFacilityId + ", level=" + level);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getFacilityIdList(parentFacilityId, level);
 	}
@@ -367,6 +388,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<String> getNodeFacilityIdList(String parentFacilityId, int level) throws HinemosUnknownException {
+		m_log.debug("getNodeFacilityIdList : parentFacilityId=" + parentFacilityId + ", level=" + level);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getNodeFacilityIdList(parentFacilityId, level);
 	}
@@ -382,6 +404,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public void assignNodeScope(String parentFacilityId, String[] facilityIds) throws HinemosUnknownException {
+		m_log.debug("assignNodeScope : parentFacilityId=" + parentFacilityId + ", facilityIds=" + facilityIds);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		repository.assignNodeScope(parentFacilityId, facilityIds);
 	}
@@ -396,6 +419,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public void releaseNodeScope(String parentFacilityId, String[] facilityIds) throws HinemosUnknownException {
+		m_log.debug("releaseNodeScope : parentFacilityId=" + parentFacilityId + ", facilityIds=" + facilityIds);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		repository.releaseNodeScope(parentFacilityId, facilityIds);
 	}
@@ -416,6 +440,7 @@ public class RepositoryEndpoint {
 	 * @throws FacilityNotFoundException 
 	 */
 	public boolean isNode(String facilityId) throws HinemosUnknownException, FacilityNotFoundException {
+		m_log.debug("isNode : facilityId=" + facilityId);
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.isNode(facilityId);
 	}
@@ -427,6 +452,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<RepositoryTableInfo> getPlatformList() throws HinemosUnknownException{
+		m_log.debug("getPlatformList : ");
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getPlatformList();
 	}
@@ -438,6 +464,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<RepositoryTableInfo> getHostList() throws HinemosUnknownException{
+		m_log.debug("getHostList : ");
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getHostList();
 	}
@@ -451,6 +478,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<RepositoryTableInfo> getVmSolutionMstList() throws HinemosUnknownException{
+		m_log.debug("getVmSolutionMstList : ");
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getVmSolutionMstList();
 	}
@@ -462,6 +490,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public ArrayList<String> getVmProtocolMstList() throws HinemosUnknownException{
+		m_log.debug("getVmProtocolMstList : ");
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getVmProtocolMstList();
 	}
@@ -473,6 +502,7 @@ public class RepositoryEndpoint {
 	 * @throws HinemosUnknownException 
 	 */
 	public Date getLastUpdate() throws HinemosUnknownException{
+		m_log.debug("getLastUpdate : ");
 		RepositoryControllerLocal repository = getRepositoryControllerLocal();
 		return repository.getLastUpdate();
 	}
