@@ -148,7 +148,7 @@ fi
 #
 # set composition
 #
-if [ "x"${OPTION} = "x" ]
+if [ "x${OPTION}" = "x" ]
 then
 	if [ -d ${JBOSS_HOME}/server/all ]
 	then
@@ -166,7 +166,7 @@ fi
 #
 # cleanup JMS
 #
-if [ "x"${JMS_CLEANUP} = "xtrue" ]
+if [ "x${JMS_CLEANUP}" = "xtrue" ]
 then
 	echo
 	Logging "${MSG_I003}"
@@ -186,7 +186,7 @@ rm -f ${STARTUP_MONITOR_FILE}
 
 while [ 1 ]
 do
-	if [ "x"${JBOSS_STARTUP_WAIT} = "xfalse" ]
+	if [ "x${JBOSS_STARTUP_WAIT}" = "xfalse" ]
 	then
 			Logging "${MSG_I004} (with -W option)"
 			break
@@ -213,7 +213,7 @@ do
 	echo -n "."
 done
 
-if [ "x"${JBOSS_STARTUP_WAIT} = "xtrue" ]
+if [ "x${JBOSS_STARTUP_WAIT}" = "xtrue" ]
 then
 	# restart syslogforward (for syslogforward reconnection)
 	/bin/kill -HUP `cat /var/run/syslog-ng.pid 2> /dev/null` 2> /dev/null
