@@ -52,7 +52,7 @@ fi
 # Name resolution of Hinemos agent package
 AGENT_DIR="Hinemos_Agent-${HINEMOS_VERSION}_${VERSION}"
 AGENT_PACKAGE="hinemos_agent-${HINEMOS_VERSION}_${VERSION}.tar.gz"
-echo "インストール対象のパッケージは${AGENT_PACKAGE}です。"
+echo "Target Install Package : ${AGENT_PACKAGE}"
 
 # Variable
 scp_address=""
@@ -91,7 +91,7 @@ do
       shift
       ${LS_PROC} $1 > /dev/null
       if [ "$?" != 0 ];then
-          echo "コピー先が存在しません。"
+          echo "The copy destination doesn't exist."
           exit -1
       fi
       place=$1
@@ -109,28 +109,28 @@ done
 ## Confirmation
 ##
 
-# 入力値の確認
+# Check on input value
 if [ "${scp_address}" = "" ]; then
-    echo "Hinemosエージェントインストーラが置いてあるサーバのIPアドレスを入力して下さい。"
+    echo "Please input IP address of the server with the Hinemos agent installer."
     exit -1
 elif [ "${pass}" = "" ]; then
-    echo "Hinemosエージェントインストーラが置いてあるサーバのrootユーザのパスワードを入力して下さい。"
+    echo "Please input the password of the root user of the server with the Hinemos agent installer."
     exit -1
 elif [ "${agent}" = "" ]; then
-    echo "Hinemosエージェントインストーラのパスを入力して下さい。"
+    echo "Please input the file path of the Hinemos agent installer."
     exit -1
 elif [ "${place}" = "" ]; then
-    echo "エージェントインストーラをコピーする先を入力して下さい。"
+    echo "Please input the destination of the copy of the agent installer."
     exit -1
 elif [ "${mgr_address}" = "" ]; then
-	echo "マネージャのIPアドレスを入力してください。"
+	echo "Please input manager's IP address. "
 	exit -1 
 fi
 
 
-## エージェントインストール配布マシンの設定確認
+## Set confirmation of agent installer distribution machine
 ##
-# IPアドレスの確認とパスワードの確認
+# Confirmation of IP address and confirmation of password
 $EXPECT_PROC -c "
     set timeout 10
     spawn -noecho $SSH_PROC -n ${scp_address} -l root \"
@@ -151,15 +151,15 @@ $EXPECT_PROC -c "
 " > /dev/null
 case $? in
     1)
-      echo "IP:${scp_address}  IPアドレスが存在しません。"
+      echo "IP:${scp_address} IP address doesn't exist."
       exit 1
       ;;
     2)
-      echo "IP:${scp_address}  rootユーザのパスワードが間違っています。"
+      echo "IP:${scp_address} root user's password is wrong."
       exit 2
       ;;
     3)
-      echo "${agent}/${AGENT_PACKAGE}は存在しません。"
+      echo "${agent}/${AGENT_PACKAGE} doesn't exist."
       exit 3
       ;;
     *)
@@ -169,10 +169,10 @@ esac
 
 
 ##
-## Hinemosエージェントの処理
+## Processing on Hinemos agent server
 ##
 
-# Hinemosエージェントインストーラを入力されたIPアドレスのサーバからコピーする。
+# The Hinemos agent installer is copied from the server of input IP address. 
 $EXPECT_PROC -c "
     set timeout -1
     spawn $SCP_PROC root@${scp_address}:${agent}/${AGENT_PACKAGE} ${place}
@@ -183,36 +183,36 @@ $EXPECT_PROC -c "
 
 
 if [ $? != 0 ];then
-    echo "Hinemosエージェントインストーラのコピーに失敗しました。"
+    echo "It failed in the copy of the Hinemos agent installer."
     exit 10
 fi
-echo "Hinemosエージェントインストーラのコピーに成功しました。"
+echo "It succeeded in copying the Hinemos agent installer."
 echo "  ${place}/${AGENT_PACKAGE}"
 
-# Hinemos:エージェントの解凍
+# Hinemos agent's decompression
 CURRENT_PLACE=`${PWD_PROC}`
 cd ${place}
 ${TAR_PROC} -zxf ${AGENT_PACKAGE} > /dev/null 2>&1
 if [ $? != 0 ];then
-    echo "Hinemosエージェントの解凍に失敗しました。"
+    echo "It failed in Hinemos agent's decompression."
     exit 1
 fi
-echo "Hinemosエージェントの解凍に成功しました。"
+echo "It succeeded in Hinemos agent's decompression."
 echo "  ${place}/${AGENT_DIR}"
-echo "インストール終了後に削除してください。"
+echo "Please delete it after the installation ends."
 echo ""
-echo "インストールを開始します。"
+echo "The installation begins."
 
 cd ${CURRENT_PLACE}
 
 AGENT_LOG="${place}/${AGENT_DIR}/agent_install.log"
 
-# Hinemosエージェントのインストール
+# The Hinemos agent's installation
 $EXPECT_PROC -c "
     set timeout -1
     spawn ${place}/${AGENT_DIR}/${AGENT_INSTALL_SH}
 
-#最初のメニュー選択で1を選択
+# "1" is selected by the first menu selection. 
     expect {
         -re \".*==>\" { send \"1\r\" }
         eof { exit 1 }
@@ -220,22 +220,22 @@ $EXPECT_PROC -c "
 #    send 1\r
 
 
-#インストールを開始します。よろしいですか？(Y/N デフォルト:Y) : 
+# The installation begins. Is it good? 
     expect -re \".*\?\(Y\/N.*\).*\"
     send Y\r
 
-#インストールディレクトリは/opt/hinemos_agentでよろしいですか？ (Y/N デフォルト:Y) : 
+# Is the installation directory good in /opt/hinemos_agent ? 
     expect -re \".*\?\(Y\/N.*\).*\"
     send Y\r
 
 
-#hostsファイルのチェック
+# Check on hosts file
     expect {
 	-re \".*(Y.*\/ N.*\).*\" {send Y\r}
 	-re \".*OK.*\" {}
 	}
 
-#rpmのチェック	
+# Check on rpm file
 
     expect {
 	-re \".*\?\(Y\/N.*\).*\" {send Y\r}
@@ -243,21 +243,21 @@ $EXPECT_PROC -c "
 	}
 	
 
-#マネージャのIPアドレス設定
+# The manager's IP address setting
     expect -re \".*IP.*\"
     send ${mgr_address}\r
     expect -re \".*\(Y\/N.*\)\"
     send Y\r
 
-#サービススクリプトを配置します。よろしいですか？ (Y/N デフォルト:Y) : 
+# The service script is arranged. Is it good? 
     expect -re \".*\?\(Y\/N.*\).*\"
     send Y\r
 
-#javaインストーラでのアクション
+# Action in java installer
     expect -re \".*Do you agree to the above license terms.*\"
     send ${jre_ans}\r
 
-#再度表示されるメニュー選択で9を選択 
+# "9" is selected by the menu selection displayed again. 
     expect -re \".*==>\"
     send 9\r
     expect eof
@@ -267,10 +267,10 @@ $EXPECT_PROC -c "
 echo ""
 
 if [ $? = 0 ]; then
-    echo "Hinemosエージェントのインストールが完了しました。 ${place}の${AGENT_DIR}/agent_install.log を確認して下さい。" 
+    echo "The Hinemos agent's installation was completed. Please confirm ${AGENT_DIR}/agent_install.log of ${place}." 
 else
-    echo "Hinemosエージェントのインストールに失敗しました。 "
-    echo "詳細は、${place}の${AGENT_DIR}/agent_install.log を確認して下さい。"
+    echo "It failed in the Hinemos agent's installation."
+    echo "Please confirm ${AGENT_DIR}/agent_install.log of ${place} in detail."
     exit -1
 fi
 
