@@ -25,14 +25,14 @@ SSHKEYGEN_PROC="/usr/bin/ssh-keygen -t rsa"
 AGENT_HOME="/opt/hinemos_agent"
 AGENT_PROPERTIES="${AGENT_HOME}/lib/job_agent/Agent.properties"
 
-# 変数
+# Variables
 ip_address=""
 root_pass=""
 user=""
 pass=""
 
 ##
-## 引数格納
+## Argument setting
 ##
 while [ $# -gt 0 ] 
 do
@@ -64,40 +64,40 @@ done
 
 
 ##
-## 確認
+## Confirmation
 ##
 
-# 入力値の確認
+# Input value
 if [ "${ip_address}" = "" ]; then
-    echo "転送元IPアドレスを入力して下さい。"
+    echo "Please input forwarding former IP address."
     exit 1
 elif [ "${root_pass}" = "" ]; then
-    echo "転送元rootユーザのパスワードを入力して下さい。"
+    echo "Please input forwarding former root user's password."
     exit 1
 elif [ "${user}" = "" ]; then
-    echo "ファイル転送実行ユーザ名を入力して下さい。"
+    echo "Please input the file transfer execution user-name."
     exit 1
 elif [ "${pass}" = "" ]; then
-    echo "ファイル転送実行ユーザのパスワードを入力して下さい。"
+    echo "Please input file transfer execution user's password."
     exit 1
 fi
 
-## 転送先
-# 転送ユーザの確認(転送先)
+## Forwarding site
+# The forwarding user's confirmation (forwarding site)
 if [ "`cat /etc/passwd | ${GREP_PROC} ^${user}:`" = "" ]; then
-    echo "${user}は存在しません。"
+    echo "${user} doesn't exist."
     exit 1
 fi
 
-# Hinemosエージェントの確認
+# The Hinemos agent's confirmation
 if [ ! -f ${AGENT_PROPERTIES} ]; then
-    echo "${HOSTNAME}にHinemosエージェントがインストールされていません。"
+    echo "The Hinemos agent is not installed in ${HOSTNAME}."
     exit 1 
 fi
 
 
-## 転送元
-# IPアドレスの確認とパスワードの確認
+## Forwarding origin
+# Confirmation of IP address and confirmation of password
 $EXPECT_PROC -c "
     set timeout 1
     spawn -noecho $SSH_PROC -n ${ip_address} -l root
@@ -115,11 +115,11 @@ $EXPECT_PROC -c "
 " > /dev/null
 case $? in
     1)
-      echo "IP:${ip_address}  IPアドレスが存在しません。"
+      echo "IP:${ip_address} IP address doesn't exist. "
       exit 1
       ;;
     2)
-      echo "IP:${ip_address}  rootユーザのパスワードが間違っています。"
+      echo "IP:${ip_address} Root user's password is wrong."
       exit 1
       ;;
     *)
@@ -127,7 +127,7 @@ case $? in
       ;;
 esac
 
-# 転送ユーザの確認とエージェントの確認
+# Confirmation of forwarding user and the agent's confirmation
 $EXPECT_PROC -c "
     set timeout 1
     spawn -noecho $SSH_PROC -n ${ip_address} -l ${user} \"
@@ -143,11 +143,11 @@ $EXPECT_PROC -c "
 " > /dev/null
 case $? in
     1)
-      echo "IP:${ip_address}  ${user}が存在しないか、${user}のパスワードが間違っています。" 
+      echo "IP:${ip_address} ${user} doesn't exist or the password of ${user} is wrong." 
       exit 1
       ;;
     2)
-      echo "IP:${ip_address}  Hinemosエージェントがインストールされていません。"
+      echo "IP:${ip_address} The Hinemos agent is not installed."
       exit 1
       ;;
     *)
@@ -159,10 +159,10 @@ esac
 
 
 ##
-## 転送先の設定
+## Setting of forwarding site
 ##
 
-# 転送ユーザの公開鍵を作成する
+# Forwarding user's public key is made.
 $SU_PROC - $user -c "
     if [ ! -f ${user_home}/.ssh/id_rsa.pub ]; then
         $EXPECT_PROC -c \"
@@ -179,7 +179,7 @@ $SU_PROC - $user -c "
 "  > /dev/null
 
 
-# Hinemosエージェントへ転送ユーザの公開鍵を登録する
+# Forwarding user's public key is registered to the Hinemos agent.
 if [ -f ${AGENT_PROPERTIES} ]; then
 
     TMP_KEY="${user}.public.key=`cat ${user_home}/.ssh/id_rsa.pub`"
@@ -187,13 +187,13 @@ if [ -f ${AGENT_PROPERTIES} ]; then
         echo $TMP_KEY >> ${AGENT_PROPERTIES}
     fi
 
-else # Hinemosエージェントがインストールされていない場合。
-    echo "Hinemosエージェントがインストールされていません。"
+else # When the Hinemos agent is not installed.
+    echo "The Hinemos agent is not installed."
     exit 1
 fi 
 
 
-# 転送ユーザのknown_hostsに転送先のホスト鍵を登録する
+# The host key to the forwarding site is registered in forwarding user's known_hosts.
 $SU_PROC - $user -c "
     $EXPECT_PROC -c \"
         set timeout 1
@@ -210,10 +210,10 @@ $SU_PROC - $user -c "
 
 
 ##
-## 転送元の設定
+## Setting of forwarding origin
 ##
 
-# 転送ユーザにauthorized_keysファイルを作成する
+# The authorized_keys file is made for the forwarding user. 
 $EXPECT_PROC -c "
     set timeout 1
     spawn $SSH_PROC -n ${ip_address} -l ${user} \"
@@ -227,7 +227,7 @@ $EXPECT_PROC -c "
 " > /dev/null
 
 
-# 転送元のAgent.propertiesに転送ユーザのauthorized_keysのパスを登録する
+# Path forwarding user's authorized_keys is registered in Agent.properties in the forwarding origin. 
 $EXPECT_PROC -c "
     set timeout 1
     spawn -noecho $SSH_PROC -n ${ip_address} -l root \"
@@ -240,5 +240,5 @@ $EXPECT_PROC -c "
     expect eof
 " > /dev/null
 
-echo "設定が正常に終了しました。"
+echo "The setting ended normally."
 exit
