@@ -62,126 +62,6 @@ ALTER TABLE ONLY cc_vm_solution_mst
 ALTER TABLE cc_vm_solution_mst CLUSTER ON cc_vm_solution_mst_pkey;
 
 
---
--- Name: hilo_pk; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY hilosequences
-    ADD CONSTRAINT hilo_pk PRIMARY KEY (sequencename);
-
-ALTER TABLE hilosequences CLUSTER ON hilo_pk;
-
-
---
--- Name: jbm_counter_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_counter
-    ADD CONSTRAINT jbm_counter_pkey PRIMARY KEY (name);
-
-ALTER TABLE jbm_counter CLUSTER ON jbm_counter_pkey;
-
-
---
--- Name: jbm_dual_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_dual
-    ADD CONSTRAINT jbm_dual_pkey PRIMARY KEY (dummy);
-
-ALTER TABLE jbm_dual CLUSTER ON jbm_dual_pkey;
-
-
---
--- Name: jbm_id_cache_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_id_cache
-    ADD CONSTRAINT jbm_id_cache_pkey PRIMARY KEY (node_id, cntr);
-
-ALTER TABLE jbm_id_cache CLUSTER ON jbm_id_cache_pkey;
-
-
---
--- Name: jbm_msg_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_msg
-    ADD CONSTRAINT jbm_msg_pkey PRIMARY KEY (message_id);
-
-ALTER TABLE jbm_msg CLUSTER ON jbm_msg_pkey;
-
-
---
--- Name: jbm_msg_ref_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_msg_ref
-    ADD CONSTRAINT jbm_msg_ref_pkey PRIMARY KEY (message_id, channel_id);
-
-ALTER TABLE jbm_msg_ref CLUSTER ON jbm_msg_ref_pkey;
-
-
---
--- Name: jbm_postoffice_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_postoffice
-    ADD CONSTRAINT jbm_postoffice_pkey PRIMARY KEY (postoffice_name, node_id, queue_name);
-
-ALTER TABLE jbm_postoffice CLUSTER ON jbm_postoffice_pkey;
-
-
---
--- Name: jbm_role_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_role
-    ADD CONSTRAINT jbm_role_pkey PRIMARY KEY (user_id, role_id);
-
-ALTER TABLE jbm_role CLUSTER ON jbm_role_pkey;
-
-
---
--- Name: jbm_tx_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_tx
-    ADD CONSTRAINT jbm_tx_pkey PRIMARY KEY (transaction_id);
-
-ALTER TABLE jbm_tx CLUSTER ON jbm_tx_pkey;
-
-
---
--- Name: jbm_user_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jbm_user
-    ADD CONSTRAINT jbm_user_pkey PRIMARY KEY (user_id);
-
-ALTER TABLE jbm_user CLUSTER ON jbm_user_pkey;
-
-
---
--- Name: jms_message_log_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jms_message_log
-    ADD CONSTRAINT jms_message_log_pkey PRIMARY KEY (messageid, destination);
-
-ALTER TABLE jms_message_log CLUSTER ON jms_message_log_pkey;
-
-
---
--- Name: jms_reference_log_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY jms_reference_log
-    ADD CONSTRAINT jms_reference_log_pkey PRIMARY KEY (messageid, destination);
-
-ALTER TABLE jms_reference_log CLUSTER ON jms_reference_log_pkey;
-
-
 --
 -- Name: p_key_cc_acc_lock; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -1412,16 +1292,6 @@ ALTER TABLE ONLY qrtz_triggers
 ALTER TABLE qrtz_triggers CLUSTER ON qrtz_triggers_pkey;
 
 
---
--- Name: timers_pk; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace: 
---
-
-ALTER TABLE ONLY timers
-    ADD CONSTRAINT timers_pk PRIMARY KEY (timerid, targetid);
-
-ALTER TABLE timers CLUSTER ON timers_pk;
-
-
 --
 -- Name: cc_cfg_node_hostname_idx_hostname; Type: INDEX; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -1548,13 +1418,6 @@ CREATE INDEX idx_qrtz_t_nf_st ON qrtz_triggers USING btree (trigger_state, next_
 CREATE INDEX idx_qrtz_t_state ON qrtz_triggers USING btree (trigger_state);
 
 
---
--- Name: jbm_msg_ref_tx; Type: INDEX; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE INDEX jbm_msg_ref_tx ON jbm_msg_ref USING btree (transaction_id, state);
-
-
 --
 -- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: hinemos
 --
@@ -2466,6 +2329,102 @@ GRANT ALL ON SCHEMA public TO hinemos;
 GRANT ALL ON SCHEMA public TO PUBLIC;
 
 
+--
+-- JBoss Remoting/Messaging Schema
+--
+
+--
+-- Name: jbm_counter_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_counter
+    ADD CONSTRAINT jbm_counter_pkey PRIMARY KEY (name);
+
+
+--
+-- Name: jbm_dual_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_dual
+    ADD CONSTRAINT jbm_dual_pkey PRIMARY KEY (dummy);
+
+
+--
+-- Name: jbm_id_cache_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_id_cache
+    ADD CONSTRAINT jbm_id_cache_pkey PRIMARY KEY (node_id, cntr);
+
+
+--
+-- Name: jbm_msg_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_msg
+    ADD CONSTRAINT jbm_msg_pkey PRIMARY KEY (message_id);
+
+
+--
+-- Name: jbm_msg_ref_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_msg_ref
+    ADD CONSTRAINT jbm_msg_ref_pkey PRIMARY KEY (message_id, channel_id);
+
+
+--
+-- Name: jbm_postoffice_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_postoffice
+    ADD CONSTRAINT jbm_postoffice_pkey PRIMARY KEY (postoffice_name, node_id, queue_name);
+
+
+--
+-- Name: jbm_role_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_role
+    ADD CONSTRAINT jbm_role_pkey PRIMARY KEY (user_id, role_id);
+
+--
+-- Name: jbm_tx_ex_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_tx_ex
+    ADD CONSTRAINT jbm_tx_ex_pkey PRIMARY KEY (transaction_id);
+
+
+--
+-- Name: jbm_tx_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_tx
+    ADD CONSTRAINT jbm_tx_pkey PRIMARY KEY (transaction_id);
+
+
+--
+-- Name: jbm_user_pkey; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY jbm_user
+    ADD CONSTRAINT jbm_user_pkey PRIMARY KEY (user_id);
+
+--
+-- Name: jbm_msg_ref_tx; Type: INDEX; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE INDEX jbm_msg_ref_tx ON jbm_msg_ref USING btree (transaction_id, state);
+
+--
+-- Name: timers_pk; Type: CONSTRAINT; Schema: public; Owner: hinemos; Tablespace:
+--
+
+ALTER TABLE ONLY timers
+    ADD CONSTRAINT timers_pk PRIMARY KEY (timerid, targetid);
+
+
 --
 -- PostgreSQL database dump complete
 --
