@@ -867,7 +867,7 @@ CREATE TABLE cc_job_param_info (
     param_id character varying(64) NOT NULL,
     param_type smallint NOT NULL,
     description character varying(256),
-    value character varying(1024)
+    value text
 );
 
 
@@ -883,7 +883,7 @@ CREATE TABLE cc_job_param_mst (
     param_id character varying(64) NOT NULL,
     param_type smallint NOT NULL,
     description character varying(256),
-    value character varying(1024)
+    value text
 );
 
 
@@ -2000,191 +2000,6 @@ CREATE TABLE cc_vm_solution_mst (
 
 ALTER TABLE public.cc_vm_solution_mst OWNER TO hinemos;
 
---
--- Name: hilosequences; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE hilosequences (
-    sequencename character varying(50) NOT NULL,
-    highvalues integer NOT NULL
-);
-
-
-ALTER TABLE public.hilosequences OWNER TO hinemos;
-
---
--- Name: jbm_counter; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_counter (
-    name character varying(255) NOT NULL,
-    next_id bigint
-);
-
-
-ALTER TABLE public.jbm_counter OWNER TO hinemos;
-
---
--- Name: jbm_dual; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_dual (
-    dummy integer NOT NULL
-);
-
-
-ALTER TABLE public.jbm_dual OWNER TO hinemos;
-
---
--- Name: jbm_id_cache; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_id_cache (
-    node_id integer NOT NULL,
-    cntr integer NOT NULL,
-    jbm_id character varying(255)
-);
-
-
-ALTER TABLE public.jbm_id_cache OWNER TO hinemos;
-
---
--- Name: jbm_msg; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_msg (
-    message_id bigint NOT NULL,
-    reliable character(1),
-    expiration bigint,
-    "timestamp" bigint,
-    priority smallint,
-    type smallint,
-    headers bytea,
-    payload bytea
-);
-
-
-ALTER TABLE public.jbm_msg OWNER TO hinemos;
-
---
--- Name: jbm_msg_ref; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_msg_ref (
-    message_id bigint NOT NULL,
-    channel_id bigint NOT NULL,
-    transaction_id bigint,
-    state character(1),
-    ord bigint,
-    page_ord bigint,
-    delivery_count integer,
-    sched_delivery bigint
-);
-
-
-ALTER TABLE public.jbm_msg_ref OWNER TO hinemos;
-
---
--- Name: jbm_postoffice; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_postoffice (
-    postoffice_name character varying(255) NOT NULL,
-    node_id integer NOT NULL,
-    queue_name character varying(255) NOT NULL,
-    cond character varying(1023),
-    selector character varying(1023),
-    channel_id bigint,
-    clustered character(1),
-    all_nodes character(1)
-);
-
-
-ALTER TABLE public.jbm_postoffice OWNER TO hinemos;
-
---
--- Name: jbm_role; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_role (
-    role_id character varying(32) NOT NULL,
-    user_id character varying(32) NOT NULL
-);
-
-
-ALTER TABLE public.jbm_role OWNER TO hinemos;
-
---
--- Name: jbm_tx; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_tx (
-    node_id integer,
-    transaction_id bigint NOT NULL,
-    branch_qual bytea,
-    format_id integer,
-    global_txid bytea
-);
-
-
-ALTER TABLE public.jbm_tx OWNER TO hinemos;
-
---
--- Name: jbm_user; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jbm_user (
-    user_id character varying(32) NOT NULL,
-    passwd character varying(32) NOT NULL,
-    clientid character varying(128)
-);
-
-
-ALTER TABLE public.jbm_user OWNER TO hinemos;
-
---
--- Name: jms_message_log; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jms_message_log (
-    messageid integer NOT NULL,
-    destination character varying(255) NOT NULL,
-    txid integer,
-    txop character(1),
-    lateclone character(1),
-    messageblob bytea
-);
-
-
-ALTER TABLE public.jms_message_log OWNER TO hinemos;
-
---
--- Name: jms_reference_log; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jms_reference_log (
-    messageid integer NOT NULL,
-    destination character varying(256) NOT NULL,
-    txid integer,
-    txop character(1),
-    redelivered character(1),
-    redelivers integer
-);
-
-
-ALTER TABLE public.jms_reference_log OWNER TO hinemos;
-
---
--- Name: jms_transaction_log; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
---
-
-CREATE TABLE jms_transaction_log (
-    txid integer
-);
-
-
-ALTER TABLE public.jms_transaction_log OWNER TO hinemos;
-
 --
 -- Name: maintenance_info; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
 --
@@ -2415,7 +2230,163 @@ CREATE TABLE qrtz_triggers (
 ALTER TABLE public.qrtz_triggers OWNER TO hinemos;
 
 --
--- Name: timers; Type: TABLE; Schema: public; Owner: hinemos; Tablespace: 
+-- Name: public; Type: ACL; Schema: -; Owner: hinemos
+--
+
+REVOKE ALL ON SCHEMA public FROM PUBLIC;
+REVOKE ALL ON SCHEMA public FROM hinemos;
+GRANT ALL ON SCHEMA public TO hinemos;
+GRANT ALL ON SCHEMA public TO PUBLIC;
+
+
+--
+-- JBoss Remoting/Messaging Schema
+--
+
+
+--
+-- Name: jbm_counter; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_counter (
+    name character varying(255) NOT NULL,
+    next_id bigint
+);
+
+
+ALTER TABLE public.jbm_counter OWNER TO hinemos;
+
+--
+-- Name: jbm_dual; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_dual (
+    dummy integer NOT NULL
+);
+
+
+ALTER TABLE public.jbm_dual OWNER TO hinemos;
+
+--
+-- Name: jbm_id_cache; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_id_cache (
+    node_id integer NOT NULL,
+    cntr integer NOT NULL,
+    jbm_id character varying(255)
+);
+
+ALTER TABLE public.jbm_id_cache OWNER TO hinemos;
+
+--
+-- Name: jbm_msg; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_msg (
+    message_id bigint NOT NULL,
+    reliable character(1),
+    expiration bigint,
+    "timestamp" bigint,
+    priority smallint,
+    type smallint,
+    headers bytea,
+    payload bytea
+);
+
+
+ALTER TABLE public.jbm_msg OWNER TO hinemos;
+
+--
+-- Name: jbm_msg_ref; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_msg_ref (
+    message_id bigint NOT NULL,
+    channel_id bigint NOT NULL,
+    transaction_id bigint,
+    state character(1),
+    ord bigint,
+    page_ord bigint,
+    delivery_count integer,
+    sched_delivery bigint
+);
+
+
+ALTER TABLE public.jbm_msg_ref OWNER TO hinemos;
+
+--
+-- Name: jbm_postoffice; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_postoffice (
+    postoffice_name character varying(255) NOT NULL,
+    node_id integer NOT NULL,
+    queue_name character varying(255) NOT NULL,
+    cond character varying(1023),
+    selector character varying(1023),
+    channel_id bigint,
+    clustered character(1),
+    all_nodes character(1)
+);
+
+
+ALTER TABLE public.jbm_postoffice OWNER TO hinemos;
+
+--
+-- Name: jbm_role; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_role (
+    role_id character varying(32) NOT NULL,
+    user_id character varying(32) NOT NULL
+);
+
+
+ALTER TABLE public.jbm_role OWNER TO hinemos;
+
+--
+-- Name: jbm_tx; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_tx (
+    node_id integer,
+    transaction_id bigint NOT NULL,
+    branch_qual bytea,
+    format_id integer,
+    global_txid bytea
+);
+
+
+ALTER TABLE public.jbm_tx OWNER TO hinemos;
+
+--
+-- Name: jbm_tx_ex; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_tx_ex (
+    transaction_id bigint NOT NULL,
+    start_time bigint
+);
+
+
+ALTER TABLE public.jbm_tx_ex OWNER TO hinemos;
+
+--
+-- Name: jbm_user; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
+--
+
+CREATE TABLE jbm_user (
+    user_id character varying(32) NOT NULL,
+    passwd character varying(32) NOT NULL,
+    clientid character varying(128)
+);
+
+
+ALTER TABLE public.jbm_user OWNER TO hinemos;
+
+--
+-- Name: timers; Type: TABLE; Schema: public; Owner: hinemos; Tablespace:
 --
 
 CREATE TABLE timers (
@@ -2431,16 +2402,6 @@ CREATE TABLE timers (
 ALTER TABLE public.timers OWNER TO hinemos;
 
 
---
--- Name: public; Type: ACL; Schema: -; Owner: hinemos
---
-
-REVOKE ALL ON SCHEMA public FROM PUBLIC;
-REVOKE ALL ON SCHEMA public FROM hinemos;
-GRANT ALL ON SCHEMA public TO hinemos;
-GRANT ALL ON SCHEMA public TO PUBLIC;
-
-
 --
 -- PostgreSQL database dump complete
 --
